# force out-of-tree build for spec compatibility with older releases
%undefine __cmake_in_source_build

%global forgeurl https://github.com/Brewtarget/brewtarget

%global _description %{expand:
Brewtarget is an open source beer recipe creation tool. It automatically
calculates color, bitterness, and other parameters for you while you drag and
drop ingredients into the recipe. Brewtarget also has many other tools such as
priming sugar calculators, OG correction help, and a unique mash designing tool.
It also can export and import recipes in BeerXML.}

Name:           brewtarget
Version:        3.0.4
Release:        1%{?dist}
Summary:        An open source beer recipe creation tool 🍺
%forgemeta
# BSD-2-Clause: cmake/modules/FindPhonon.cmake
# WTFPL: images/flag* images/bubbles.svg images/convert.svg images/grain2glass.svg
# CC-BY-SA-3.0 OR LGPL-3.0-only: images/edit-copy.png images/document-print-preview.png
#     images/merge.png images/preferences-other.png images/printer.png
#     images/server-database.png images/kbruch.png images/help-contents.png
# LGPL-2.1-only: images/backup.png
License:    GPL-3.0-or-later AND BSD-2-Clause AND WTFPL AND (CC-BY-SA-3.0 OR LGPL-3.0-only) AND LGPL-2.1-only
URL:        %{forgeurl}
Source0:    %{forgesource}

BuildRequires:  gcc-c++
BuildRequires:  qt5-qtbase-devel, qt5-qtwebkit-devel, qt5-qtsvg-devel
BuildRequires:  qt5-qtmultimedia-devel, qt5-linguist
BuildRequires:  boost-devel, xerces-c-devel, xalan-c-devel
BuildRequires:  desktop-file-utils
Requires:       sqlite

%description %_description

%prep
%setup -q -n %{name}-%{version}

%build
%cmake -DDO_RELEASE_BUILD:BOOL=ON
%cmake_build

%install
%cmake_install
# Remove generated files. We use what's provided in tarball.
rm %buildroot/%{_docdir}/%{name}/{RelaseNotes.markdown,changelog.Debian.gz,copyright}
gzip doc/brewtarget.1
/usr/bin/install -m 0644 -Dp doc/brewtarget.1.gz %buildroot%{_mandir}/man1/brewtarget.1.gz
# symlink manual, which is accessible in application
rm %buildroot/%{_datadir}/%{name}/manual-en.pdf
pushd %buildroot/%{_datadir}/%{name}
ln -s ../doc/%{name}/manual-en.pdf .
popd

%check
desktop-file-validate %buildroot%{_datadir}/applications/%{name}.desktop

%files
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_mandir}/man1/brewtarget*
%doc CHANGES.markdown README.markdown doc/manual-en.pdf
%license COPYRIGHT COPYING.GPLv3 COPYING.WTFPL

%changelog
* Tue Nov 29 2022 Sandro <devel@penguinpee.nl> 3.0.4-1
- Update to 3.0.4 (RHBZ#2149053)
- Fix desktop file location

* Wed Nov 23 2022 Sandro <devel@penguinpee.nl> 3.0.3-4
- Drop definition of tag

* Wed Nov 23 2022 Sandro <devel@penguinpee.nl> 3.0.3-3
- Ignore tab to space conversion

* Wed Nov 23 2022 Sandro <devel@penguinpee.nl> 3.0.3-2
- Convert tabs to spaces

* Sat Nov 12 2022 Sandro <devel@penguinpee.nl> 3.0.3-1
- Update to 3.0.2 (RHBZ#2140886)
- SPDX migration

* Fri Oct 28 2022 Sandro <devel@penguinpee.nl> 3.0.2-1
- Update to 3.0.2 (RHBZ#2134223)
- Update dependencies
- Update and clarify licenses
- Use %%forgemeta and %%autochangelog
- Replace BR cmake with gcc-c++

* Wed Jul 20 2022 Fedora Release Engineering <releng@fedoraproject.org> 2.1.0-25
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Wed Jan 19 2022 Fedora Release Engineering <releng@fedoraproject.org> 2.1.0-24
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Wed Jul 21 2021 Fedora Release Engineering <releng@fedoraproject.org> 2.1.0-23
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Wed Jul 21 2021 Fedora Release Engineering <releng@fedoraproject.org> 2.1.0-22
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Tue Jan 26 2021 Fedora Release Engineering <releng@fedoraproject.org> 2.1.0-21
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Thu Aug 06 2020 Fabio Valentini <decathorpe@gmail.com> 2.1.0-20
- adaptations for CMake out-of-tree builds

* Sat Aug 01 2020 Fedora Release Engineering <releng@fedoraproject.org> 2.1.0-19
- Second attempt - Rebuilt for
  https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Mon Jul 27 2020 Fedora Release Engineering <releng@fedoraproject.org> 2.1.0-18
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Tue Jan 28 2020 Fedora Release Engineering <releng@fedoraproject.org> 2.1.0-17
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Mon Sep 16 2019 Kevin Fenzi <kevin@scrye.com> 2.1.0-16
- Fix FTBFS bug #1734987

* Wed Jul 24 2019 Fedora Release Engineering <releng@fedoraproject.org> 2.1.0-15
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Thu Jan 31 2019 Fedora Release Engineering <releng@fedoraproject.org> 2.1.0-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Mon Jan 28 2019 Igor Gnatenko <ignatenkobrain@fedoraproject.org> 2.1.0-12
- Remove obsolete Group tag

* Thu Jul 12 2018 Fedora Release Engineering <releng@fedoraproject.org> 2.1.0-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> 2.1.0-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Wed Aug 02 2017 Fedora Release Engineering <releng@fedoraproject.org> 2.1.0-9
- Rebuilt for
  https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> 2.1.0-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Mon May 15 2017 Fedora Release Engineering <releng@fedoraproject.org> 2.1.0-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> 2.1.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Wed Feb 03 2016 Dennis Gilmore <dennis@ausil.us> 2.1.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Aug 27 2015 Pete Travis <immanetize@fedoraproject.org> 2.1.0-4
- changing upstream source repo.  Also sending email upstream asking for
  tags...

* Wed Jun 17 2015 Dennis Gilmore <dennis@ausil.us> 2.1.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> 2.1.0-2
- Rebuilt for GCC 5 C++11 ABI change

* Wed Nov 12 2014 Pete Travis <immanetize@fedoraproject.org> 2.1.0-1
- upstream 2.1.0
- add sqlite runtime req, because it uses that
- icon dir change
- new features

* Fri Aug 15 2014 Peter Robinson <pbrobinson@fedoraproject.org> 2.0.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Dennis Gilmore <dennis@ausil.us> 2.0.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Tue Feb 18 2014 Pete Travis <immanetize@fedoraproject.org> 2.0.2-3
- updating %%doc

* Mon Feb 17 2014 Pete Travis <immanetize@fedoraproject.org> 2.0.2-1
- updating spec for brewtarget 2.0.2

* Sat Aug 03 2013 Pete Travis <immanetize@fedoraproject.org> 2.0.1-1
- Updating to version 2.0.1 - New recipes - Bugfixes that may or may not be
  logged upstream, - Improved recipe creation logic - SQL backend option

* Sat Aug 03 2013 Dennis Gilmore <dennis@ausil.us> 1.2.5-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Feb 13 2013 Dennis Gilmore <dennis@ausil.us> 1.2.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sat Nov 24 2012 Pete Travis <immanetize@fedoraproject.org> 1.2.5-2
- Initial import (#876865)

* Wed Nov 21 2012 Pete Travis <immanetize@fedoraproject.org> 1.2.5-1
- Initial import (#876865)
